%parasail_model
%
% A simple model of a parasail.
%
% LAST UPDATED by Andy French. August 2013.
%
% Assumptions:
%
% * Dynamic equilibrium, for a given boat velocity
% * Lift and drag forces on the parachute have no dependence on the angle
%   of attack. This is NOT a good assumption, but will make the analysis
%   possible. In general we would expect both to vary significantly over
%   the range of angles.

function parasail_model

%% INPUTS %%

%Define number of data points
N = 1000;

%Fontsize of graphs
fsize = 16;

%Density of air /kgm^-3
rho = 1;

%Cross sectional area of passenger & harness
D = 1;

%Radius of parachute /m
R = 4;

%Mass of parachute /kg
m = 10;

%Drag coefficient of passenger
c1 = 1;

%Drag coefficient of parachute 
c2 = 1;

%Lift coefficient of parachute
cL = 10;

%Minimum and maximum mass of passenger + harness /kg
Mmin = 0;
Mmax = 200;

%1 ms^-1 in knots
one_mps_in_knots = 1.944;

%Gravitational field strength /ms^-2
g = 9.81;

%%

%Compute drag and lift parameters
k1 = 0.5*c1*rho*D;
k2 = 0.5*c2*rho*pi*R^2;
kL = 0.5*cL*rho*pi*R^2;

%Construct matrices of passenger masses and tow cable angles.
%All derived quantities below will be matricies relative to these
%variables.
M = linspace(Mmin,Mmax,N);
theta = linspace(pi/6,pi/2,N);
[M,theta] = meshgrid(M,theta);
theta_deg = 180*theta/pi;

%Compute velocity of boat required /ms^-1
v = sqrt( ( (M+m)*g/k2 )./( kL/k2 - (1+k1/k2)*tan(theta)  ) );

%Compute angle of parachute normal from tow cable /degrees
phi = atan( (kL*v.^2 -m*g)./(k2*v.^2) ) - theta;
phi_deg = 180*phi/pi;

%Compute tension in parachute cords /N
T2 = ( k2*v.^2 )./cos(phi + theta);

%Compute cable tension in tow cable /N
T1 = (-M*g + T2.*sin(theta+phi) )./sin(theta);

%Determine minimum tow boat velocity /ms^-1
vmin = sqrt( (M+m)*g/(kL) );

%Determine minimum tow cable angle /deg
theta_max = atan( (kL/k2)/(1+k1/k2) );
theta_max_deg = theta_max*180/pi;

%Set NaN elements when v < vmin  & theta > theta_max
check = find( ( v < vmin ) | ( theta > theta_max ) ) ;
v( check ) = NaN;
phi_deg( check ) = NaN;
T1( check ) = NaN;
T2( check ) = NaN;

%%

%Plot graphs
fig = figure('name','parasail model','color',[1 1 1] );
interp_colormap(N);

%v vs M and theta
surf( M, theta_deg,  v*one_mps_in_knots  );
shading interp
set(gca,'fontsize',fsize)
xlabel('M /kg','fontsize',fsize );
ylabel('\theta /deg','fontsize',fsize );
zlabel('v /knots','fontsize',fsize );
title('Boat velocity /knots vs tow angle and passenger mass')
view(2);
axis tight
colorbar
caxis([0,10])
print( gcf,'v vs M and theta','-dpng','-r300' )
clf

%

%phi vs M and theta
surf( M, theta_deg, phi_deg );
shading interp
set(gca,'fontsize',fsize)
xlabel('M /kg','fontsize',fsize );
ylabel('\theta /deg','fontsize',fsize );
zlabel('\phi','fontsize',fsize );
title('Parachute cord elevation from tow cable \phi /deg')
view(2);
axis tight
colorbar
caxis([0,90])
print( gcf,'phi vs M & v','-dpng','-r300' )
clf

%

%T1 vs M and theta
surf( M, theta_deg, T1 );
shading interp
set(gca,'fontsize',fsize)
xlabel('M /kg','fontsize',fsize );
ylabel('\theta /deg','fontsize',fsize );
zlabel('T_1 /N','fontsize',fsize );
title('Tow cable tension /N')
view(2);
axis tight
colorbar
caxis([0,3000])
print( gcf,'tow cable tension','-dpng','-r300' )
clf

%

%T2 vs M and theta
surf( M, theta_deg, T2 );
shading interp
set(gca,'fontsize',fsize)
xlabel('M /kg','fontsize',fsize );
ylabel('\theta /deg','fontsize',fsize );
zlabel('T_2 /N','fontsize',fsize );
title('Parachute cord tension /N')
view(2);
axis tight
colorbar
caxis([0,3000])
print( gcf,'parachute cord tension','-dpng','-r300' )
clf

%Close figure
close(gcf);

%%

%interp_colormap
% Function which interpolates current colourmap to yield better graduated
% shading. N is number of possible colours.
function interp_colormap( N )

%Get current colourmap
map = colormap;

%Initialise new colormap
new_map = ones(N,3);

%Get size of current colormap and initalise red,green,blue vectors
dim = size(map);
R = ones(1,dim(1));
G = ones(1,dim(1));
B = ones(1,dim(1));
RR = ones(1,N);
GG = ones(1,N);
BB = ones(1,N);

%Populate these with current colormap
R(:) = map(:,1);
G(:) = map(:,2);
B(:) = map(:,3);

%Interpolate to yield new colour map
x = linspace( 1, dim(1), N );
RR = interp1( 1:dim(1), R, x );
GG = interp1( 1:dim(1), G, x );
BB = interp1( 1:dim(1), B, x );
new_map(:,1) = RR(:);
new_map(:,2) = GG(:);
new_map(:,3) = BB(:);

%Set colormap to be new map
colormap( new_map );

%End of code